@@ -107,9 +107,6 @@ class Irradiance():
 
     cols = ['Rb_front', 'Rb_rear']
     data[cols] = data[cols].clip(upper=5)
-    
-    data[['GHI', 'DHI','DNI']] = data[['GHI', 'DHI','DNI']].clip(lower=0)
-
 
     data['DOY'] = DOY
     data['Solar Zenith angle'] = psi
@@ -144,6 +141,8 @@ class Irradiance():
 
     if module['BIPV'] == 'N' :
       data['Total_G'] = G_front
+      data[['GHI', 'DHI','DNI','G_Front','Total_G']] = data[['GHI', 'DHI','DNI','G_Front','Total_G']].clip(lower=0)
+
       return inputs ,data, metadata
 
 
@@ -154,6 +153,8 @@ class Irradiance():
     G_Rear = GR_beam + GR_diffuse + GR_reflected
     data['G_Rear'] = G_Rear
     data['Total_G'] = G_Rear + G_front
+    data[['GHI', 'DHI','DNI','G_Front','Total_G','G_Rear']] = data[['GHI', 'DHI','DNI','G_Front','Total_G','G_Rear']].clip(lower=0)
+
 
     return inputs ,data, metadata
 
